@@ -1,4 +1,7 @@
 package Test::LectroTest::Generator;
+{
+  $Test::LectroTest::Generator::VERSION = '0.5000';
+}
 
 use strict;
 use warnings;
@@ -25,12 +28,15 @@ BEGIN {
 }
 
 our @EXPORT_OK;
-our $VERSION = "0.14";
 
 =head1 NAME
 
 Test::LectroTest::Generator - Random value generators and combinators
 
+=head1 VERSION
+
+version 0.5000
+
 =head1 SYNOPSIS
 
  use Test::LectroTest::Generator qw(:common :combinators);
@@ -96,7 +102,7 @@ modifier.
 The purpose of sizing is to allow LectroTest to generate simple values
 at first and then, as testing progresses, to slowly ramp up the
 complexity.  In this way, counterexamples for obvious problems
-will be easier for you to understand.  
+will be easier for you to understand.
 
 =cut
 
@@ -152,7 +158,7 @@ sub Gen(&) {
     return Test::LectroTest::Generator->new(generator=>$genfn);
 }
 
-=pod 
+=pod
 
 =head2 Generators
 
@@ -287,7 +293,7 @@ sub Float(@) {
             $lo = -$size if -$size > $lo;
             $hi =  $size if  $size < $hi;
         }
-        return $lo + rand($hi - $lo);            
+        return $lo + rand($hi - $lo);
     };
 }
 
@@ -888,6 +894,7 @@ B<Note:> This combinator does not accept modifiers.
 
 =cut
 
+sub _flatten(@);
 sub _flatten(@) {
     _concat map { ref($_) ? _flatten(@$_) : ($_) } @_ ;
 }
@@ -1137,14 +1144,6 @@ L<Test::LectroTest> gives a quick overview of automatic,
 specification-based testing with LectroTest.
 
 
-=head1 LECTROTEST HOME
-
-The LectroTest home is 
-http://community.moertel.com/LectroTest.
-There you will find more documentation, presentations, mailing-list archives, a wiki,
-and other helpful LectroTest-related resources.  It's also the
-best place to ask questions.
-
 =head1 AUTHOR
 
 Tom Moertel (tom@moertel.com)
@@ -1157,7 +1156,7 @@ http://www.cs.chalmers.se/~rjmh/QuickCheck/.
 
 =head1 COPYRIGHT and LICENSE
 
-Copyright (c) 2004-05 by Thomas G Moertel.  All rights reserved.
+Copyright (c) 2004-13 by Thomas G Moertel.  All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
